# files that must be deleted before switching maps
PRECLEAR_FILES = [
    "CellAttribute_Pde",
    "CellAttribute_Pgr",
    "CellAttribute_Pnb",
    "CellAttribute_Pnp",
    "CellAttribute_Pwd",
    "CellAttribute_Vbl",
    "CellAttribute_Vsh"
]

# files that are copied from each map's directory
COMMON_FILES = [
    "CellAttribute_Pde",
    "CellAttribute_Pgr",
    "CellAttribute_Pnb",
    "CellAttribute_Pnp",
    "CellAttribute_Pwd",
    "CellAttribute_Vbl",
    "CellAttribute_Vsh",
    "Minimap.tga",
    "MapInfo",
    "Objects",
    "Regions",
    "t3CellFlags",
    "t3FluffDoodad",
    "t3HardTile",
    "t3HeightMap",
    "t3SyncCliffLevel",
    "t3SyncHeightMap",
    "t3SyncTextureInfo",
    "t3Terrain.version",
    "t3Terrain.xml",
    "t3TextureMasks",
    "t3VertCol",
    "t3Water"
]